define(
//begin v1.x content
({
        nomatchMessage: "Пароли не совпадают.",
		badPasswordMessage: "Неправильный пароль."
})

//end v1.x content
);